@@ -63,7 +63,7 @@
 #' 
 #' @details Data sets are downloaded from the Eurostat Web Services 
 #' \href{https://wikis.ec.europa.eu/pages/viewpage.action?pageId=44165555}{SDMX API} if there is a filter otherwise the 
-#' \href{https://ec.europa.eu/eurostat/estat-navtree-portlet-prod/BulkDownloadListing}{the Eurostat bulk download facility} is used.
+#' \href{https://wikis.ec.europa.eu/display/EUROSTATHELP/Transition+-+from+Eurostat+Bulk+Download+to+API}{the Eurostat bulk download facility} is used.
 #' If only the table \code{id} is given, the whole table is downloaded from the
 #' bulk download facility. If also \code{filters} or \code{date_filter} is defined then the SDMX REST API is
 #' used. In case after filtering the dataset has more rows than the limitation of the SDMX REST API (1 million values at one time) then the bulk download is used to retrieve the whole dataset .
@@ -351,19 +351,21 @@ get_eurostat_data <- function(id,
         message("None of the filter could be applied. The whole dataset will be retrieved through bulk download.")
         restat<-restatapi::get_eurostat_bulk(id,cache,update_cache,cache_dir,compress_file,stringsAsFactors,select_freq,keep_flags,cflags,check_toc,verbose=verbose)
         if (!is.null(restat) & (verbose)) {message("get_eurostat_data - bulk restat - nrow:",nrow(restat),";ncol:",ncol(restat),";colnames:",paste(colnames(restat),collapse="/"));message("cflags:",cflags)}
-      } else  if (force_local_filter) #there is valid filter but want to filter localy, not using the API and filter url => raw download and filtering
+      } else  if (force_local_filter) #there is valid filter but want to filter locally, not using the API and filter url => raw download and filtering
       { 
-        message("Forcing to apply filter locally. The whole dataset is downloaded through the raw download and the filters are applied locally.")
+        message("Forcing to apply filter locally. The whole dataset will be downloaded through the raw download and then the filters are applied locally.")
         restat_raw<-restatapi::get_eurostat_raw(id,"txt",cache,update_cache,cache_dir,compress_file,stringsAsFactors,keep_flags,check_toc,melt=TRUE,verbose)
         if (!is.null(restat_raw) & (verbose)) {message("get_eurostat_data - raw restat - nrow:",nrow(restat_raw),";ncol:",ncol(restat_raw),";colnames:",paste(colnames(restat_raw),collapse="/"))}
         if (verbose) {message("get_eurostat_data - filter table:");print(ft)}
-        if (!is.null(dft)){
+        if (!is.null(ft)){
           if (nrow(ft)>0){restat_raw<-restatapi::filter_raw_data(restat_raw,ft)[]}
         }
+        if (!is.null(restat_raw) & (verbose)) {message("get_eurostat_data - local filtered restat_raw after ft- nrow:",nrow(restat_raw),";ncol:",ncol(restat_raw),";colnames:",paste(colnames(restat_raw),collapse="/"))}
         if (verbose) {message("get_eurostat_data - date filter table:");print(dft)}
         if (!is.null(dft)){
           if (nrow(dft)>0){restat_raw<-restatapi::filter_raw_data(restat_raw,dft,TRUE)[]}
         }
+        if (!is.null(restat_raw) & (verbose)) {message("get_eurostat_data - local filtered restat_raw after dft - nrow:",nrow(restat_raw),";ncol:",ncol(restat_raw),";colnames:",paste(colnames(restat_raw),collapse="/"))}
         cr<-FALSE
         restat<-restat_raw[]
         if (!is.null(restat) & (verbose)) {message("get_eurostat_data - local filtered restat - nrow:",nrow(restat),";ncol:",ncol(restat),";colnames:",paste(colnames(restat),collapse="/"))}
@@ -392,19 +394,23 @@ get_eurostat_data <- function(id,
                 tryCatch({rdat<-data.table::fread(text=readLines(gzcon(url(x))),sep=',',sep2=',',colClasses='character',header=TRUE,stringsAsFactors=stringsAsFactors)},
                          error = function(e) {
                            if (verbose){message("get_eurostat_data - Error by the reading in with data.table the downloaded CSV file:",'\n',paste(unlist(e),collapse="\n"))}
+                           else {message("There is an error by the reading of the CSV file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                            tbc<-FALSE
                          },
                          warning = function(w) {
                            if (verbose){message("get_eurostat_data - Warning by the reading in with data.table the downloaded CSV file:",'\n',paste(unlist(w),collapse="\n"))}
+                           else {message("There is a warning by the reading of the CSV file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                          })
               } else{
                 tryCatch({rdat<-data.table::fread(paste(readLines(gzcon(url(x))),collapse="\n"),sep=',',sep2=',',colClasses='character',header=TRUE,stringsAsFactors=stringsAsFactors)},
                          error = function(e) {
                            if (verbose){message("get_eurostat_data - Error by the reading in with data.table the downloaded CSV file:",'\n',paste(unlist(e),collapse="\n"))}
+                           else {message("There is an error by the reading of the CSV file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                            tbc<-FALSE
                          },
                          warning = function(w) {
                            if (verbose){message("get_eurostat_rdat - Warning by the reading in with data.table the downloaded CSV file:",'\n',paste(unlist(w),collapse="\n"))}
+                           else {message("There is a warning by the reading of the CSV file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                          })
               }
               if(!is.null(rdat)){
@@ -430,10 +436,12 @@ get_eurostat_data <- function(id,
               tryCatch({utils::download.file(x,temp,dmethod,quiet=!verbose)},
                        error = function(e) {
                          if (verbose) {message("get_eurostat_data - Error by the download the xml file:",'\n',paste(unlist(e),collapse="\n"))}
+                         else {message("There is an error by the download of the XML file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                          tbc<-FALSE
                        },
                        warning = function(w) {
                          if(verbose){message("get_eurostat_data - Warning by the download the xml file:",'\n',paste(unlist(w),collapse="\n"))}
+                         else {message("There is a warning by the download of the XML file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                          tbc<-FALSE
                        })
               if (length(temp)==0) {tbc<-FALSE}
@@ -442,10 +450,12 @@ get_eurostat_data <- function(id,
                 tryCatch({xml_foot<-xml2::xml_find_all(xml2::read_xml(temp),".//footer:Message")},
                          error = function(e) {
                            if (verbose) {message("get_eurostat_data - Error by the extraction of the footer from the xml:",'\n',paste(unlist(e),collapse="\n"))}
+                           else {message("There is an error by the reading of the downloaded XML file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                            tbc<-FALSE
                          },
                          warning = function(w) {
                            if(verbose){message("get_eurostat_data - Warning by the extraction of the footer from the xml:",'\n',paste(unlist(w),collapse="\n"))}
+                           else {message("There is a warning by the reading of the downloaded XML file. Run the same command with verbose=TRUE option to get more info on the issue.")}
                            tbc<-FALSE
                          })
               } 
@@ -467,11 +477,28 @@ get_eurostat_data <- function(id,
                 }
               } else {
                 tbc<-FALSE
+                tryCatch({xml_fault<-xml2::xml_find_all(xml2::read_xml(temp),".//S:Fault")},
+                        error = function(e) {
+                              if (verbose) {message("get_eurostat_data - Error by the extraction of the faultcode from the xml:",'\n',paste(unlist(e),collapse="\n"))}
+                              },
+                        warning = function(w) {
+                                if(verbose){message("get_eurostat_data - Warning by the extraction of the faultcode from the xml:",'\n',paste(unlist(w),collapse="\n"))}
+                              })
                 message("Problem by the extraction of the footer information from the xml_file.")
               }
               if(tbc){
-                tryCatch({xml_mark<-switch(rav,"1" = ".//generic:Series","2" = ".//g:Series")
-                xml_leafs<-xml2::xml_find_all(xml2::read_xml(temp),xml_mark)
+               xml_mark<-switch(rav,"1" = ".//generic:Series","2" = ".//g:Series")
+               tryCatch({xml_leafs<-xml2::xml_find_all(xml2::read_xml(temp),xml_mark)},
+                         error = function(e) {
+                                if (verbose) {message("get_eurostat_data - Error by the reading of data from the downloaded XML:",'\n',paste(unlist(e),collapse="\n"))}
+                                else {message("There is an error by the reading of the downloaded XML file. Run the same command with verbose=TRUE option to get more info on the issue.")}
+                         },
+                         warning = function(w) { 
+                           if(verbose){message("get_eurostat_data - Warning by reading of data from the downloaded XML file:",'\n',paste(unlist(w),collapse="\n"))}
+                           else {message("There is a warning by the downloaded of the XML file. Run the same command with verbose=TRUE option to get more info on the issue.")}
+                           }
+                )
+               tryCatch({           
                 if (verbose) {message(class(xml_leafs),"\nnumber of nodes: ",length(xml_leafs),"\nnumber of cores: ",getOption("restatapi_cores",1L),"\n")}
                 if (Sys.info()[['sysname']]=='Windows'){
                   if (getOption("restatapi_cores",1L)==1) {
@@ -489,7 +516,7 @@ get_eurostat_data <- function(id,
                   rdat<-data.table::rbindlist(parallel::mclapply(xml_leafs,extract_data,keep_flags=keep_flags,stringsAsFactors=stringsAsFactors,bulk=FALSE,mc.cores=getOption("restatapi_cores",1L)))                                  
                 }
                 },
-                error = function(e){rdat<-NULL},
+                error = function(e){if (verbose){message("get_eurostat_data - ",e);rdat<-NULL}},
                 warning = function(w){if (verbose){message("get_eurostat_data - ",w)}}
                 )
               }
@@ -660,9 +687,10 @@ get_eurostat_data <- function(id,
             restat$values<-suppressWarnings(as.numeric(levels(restat$values))[restat$values])        
           }
         }
-        if (is.character(restat$values)){
+        if (any(is.character(restat$values))){
           if (!any(grepl('\\d+\\:\\d+',restat$values))){
-            restat$values<-as.numeric(restat$values)
+            restat$values[grepl('^\\:$',restat$values)]<-NA
+            restat$values<-suppressWarnings(as.numeric(restat$values))
           }
         }
         restat<-unique(restat)[]
